@@ -14,6 +14,8 @@
 #include <klined.h>
 #include <qpushbutton.h>
 #include <qstring.h>
+#include <ktabctl.h>
+#include <qcheckbox.h>
 
 
 class KBlinselConfig : public QWidget
@@ -31,9 +33,14 @@ signals:
 
 private:
 
+	KTabCtl *tabctl;
 	QPushButton *confOK,*confCancel;
-	KLined *patternDir_ed,*patternSfx_ed;
+	QWidget *patternPage;
+	QWidget *advancePage;
+	QWidget *printPage;
+	KLined *patternDir_ed,*patternSfx_ed,*advanceDist_ed;
 	KConfig *tempconf;
+	QCheckBox *patternCopy;
 };
 
 #endif // KBLINSELCONFIG_H
