@@ -5,6 +5,7 @@
 #include <config.h>
 #endif 
 
+#include <stdlib.h>
 #include <kapp.h>
 #include <qwidget.h>
 #include <qlabel.h>
@@ -23,10 +24,21 @@ public:
 	virtual ~KBlinselStereogram();
 
 	QImage calc();	
+
 	void setTexture(QImage &texture);
 	void setSource(QImage &img);
+	void setMaxDistance(double maxDist);
+        void init_stg();
+        void init_field();
+        void init_texture();
+        
         bool use_texturing;
-
+        float depf, mdu;
+        float **Z;
+        int maxX, maxY, textX, textY, maxsep;
+        int **texture;
+        QImage img1;
+ 
 public slots:
 
 signals:
